==> responsebot-0.2.8.tar.gz: responsebot-0.2.8/responsebot/common/exceptions.py <==
# Copyright 2016 Invisible Institute
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
Exceptions and errors used by Tweet Bot
"""


class ResponseBotError(Exception):
    """Generic response bot error."""
    pass


class NotFreeToTweetError(ResponseBotError):
    """
    Error to indicate Tweeter fails to post some status due to Twitter API's status update rate limit.
    """
    pass


class MissingConfigError(ResponseBotError):
    """
    Exception to indicate a required configuration for Tweet Bot is not found from config file or CLI.
    """
    pass


class AuthenticationError(ResponseBotError):
    """
    Error to indicate Tweet Bot failed to authenticate with the provided credentials.
    """
    pass


class APIError(ResponseBotError):
    """Generic API error."""
    pass


class APIQuotaError(APIError):
    """
    Exception indicate some API quota breached.
    """
    pass


class UnknownAPIError(APIError):
    """
    Unknown error when executing API.
    """
    pass


class UserHandlerError(ResponseBotError):
    """
    Error to indicate some error caused by a user's handler.
    """
    def __init__(self, user_exception, msg='Error from user handler', *args, **kwargs):
        super(UserHandlerError, self).__init__(msg, *args, **kwargs)
        self.__cause__ = user_exception


class TweetError(ResponseBotError):
    """
    Error to indicate some violation of Twitter's tweet constraints (max characters, etc.)
    """
    def __init__(self, reason, *args, **kwargs):
        super(TweetError, self).__init__(*args, **kwargs)
        self.reason = reason

    def __str__(self):
        return self.reason

==> responsebot-0.4.0.tar.gz: responsebot-0.4.0/responsebot/common/exceptions.py <==
# Copyright 2016 Invisible Institute
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
Exceptions and errors used by Tweet Bot
"""


class ResponseBotError(Exception):
    """Generic response bot error."""
    pass


class NotFreeToTweetError(ResponseBotError):
    """
    Error to indicate Tweeter fails to post some status due to Twitter API's status update rate limit.
    """
    pass


class MissingConfigError(ResponseBotError):
    """
    Exception to indicate a required configuration for Tweet Bot is not found from config file or CLI.
    """
    pass


class AuthenticationError(ResponseBotError):
    """
    Error to indicate Tweet Bot failed to authenticate with the provided credentials.
    """
    pass


class AutomatedRequestError(ResponseBotError):
    """
    Error to indicate a request is deemed automated by Twitter.
    """
    pass


class OverCapacityError(ResponseBotError):
    """
    Error to indicate Twitter is currently over capacity.
    """
    pass


class DailyStatusUpdateError(ResponseBotError):
    """
    Error to indicate your account reached the daily status update limit.
    """
    pass


class CharacterLimitError(ResponseBotError):
    """
    Error to indicate your tweet reached the character limit.
    """
    pass


class APIError(ResponseBotError):
    """Generic API error."""
    pass


class APIQuotaError(APIError):
    """
    Exception indicate some API quota breached.
    """
    pass


class UnknownAPIError(APIError):
    """
    Unknown error when executing API.
    """
    pass


class UserHandlerError(ResponseBotError):
    """
    Error to indicate some error caused by a user's handler.
    """
    def __init__(self, user_exception, msg='Error from user handler', *args, **kwargs):
        super(UserHandlerError, self).__init__(msg, *args, **kwargs)
        self.__cause__ = user_exception
